mailr9505 - /1.3/generic_fns/state.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on September 10, 2009 - 19:56:
Author: bugman
Date: Thu Sep 10 19:56:32 2009
New Revision: 9505

URL: http://svn.gna.org/viewcvs/relax?rev=9505&view=rev
Log:
Updates to the load_xml() function.  This now does something!


Modified:
    1.3/generic_fns/state.py

Modified: 1.3/generic_fns/state.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/state.py?rev=9505&r1=9504&r2=9505&view=diff
==============================================================================
--- 1.3/generic_fns/state.py (original)
+++ 1.3/generic_fns/state.py Thu Sep 10 19:56:32 2009
@@ -136,9 +136,12 @@
     @type file:     file object
     """
 
-    # Make sure that the data pipe is empty.
-    if not cdp.is_empty():
-        raise RelaxError("The current data pipe is not empty.")
+    # Make sure that the data store is empty.
+    if not ds.is_empty():
+        raise RelaxError("The relax data store is not empty.")
+
+    # Load the XML.
+    ds.from_xml(file)
 
 
 def save_state(state=None, dir_name=None, compress_type=1, force=False, 
pickle=True):




Related Messages


Powered by MHonArc, Updated Thu Sep 10 20:20:06 2009